MockFormatter class

A mocktail mock.

Implemented types

Constructors

MockFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required Directory directory, required GgLog ggLog}) Future<void>
Runs the formatter against directory. Throws on failure.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited