buildMustRunScript top-level constant

String const buildMustRunScript

The script that the build script must run, so the test suite always runs as part of a build.

Implementation

const String buildMustRunScript = 'test';